/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */

export {
	typeNameSymbol,
	typeSchemaSymbol,
	type WithType,
	type TreeNodeSchema,
	NodeKind,
	type TreeNodeSchemaClass,
	type TreeNodeSchemaNonClass,
	type TreeNodeSchemaCore,
	type TreeChangeEvents,
	// TreeNode is only type exported, which prevents use of the class object for unsupported use-cases like direct sub-classing and instanceof.
	// See docs on TreeNode for more details.
	type TreeNode,
	type Unhydrated,
	type InternalTreeNode,
	isTreeNode,
	tryDisposeTreeNode,
	HydratedContext,
	SimpleContextSlot,
	getOrCreateInnerNode,
	getKernel,
} from "./core/index.js";
export {
	type ITree,
	type TreeView,
	type ViewableTree,
	type TreeViewEvents,
	TreeViewConfiguration,
	TreeViewConfigurationAlpha,
	type ITreeViewConfiguration,
	type SchemaCompatibilityStatus,
	type ITreeConfigurationOptions,
	SchemaFactory,
	SchemaFactoryAlpha,
	type SchemaFactoryObjectOptions,
	type ScopedSchemaName,
	type ValidateRecursiveSchema,
	type FixRecursiveArraySchema,
	adaptEnum,
	enumFromStrings,
	singletonSchema,
	test_RecursiveObject,
	test_RecursiveObject_base,
	test_RecursiveObjectPojoMode,
	treeNodeApi,
	type TreeNodeApi,
	cursorFromInsertable,
	createFromInsertable,
	type NodeChangedData,
	TreeBeta,
	type TreeChangeEventsBeta,
	type SimpleTreeIndex,
	type IdentifierIndex,
	createSimpleTreeIndex,
	createIdentifierIndex,
	type JsonSchemaId,
	type JsonSchemaType,
	type JsonObjectNodeSchema,
	type JsonArrayNodeSchema,
	type JsonMapNodeSchema,
	type JsonLeafNodeSchema,
	type JsonSchemaRef,
	type JsonRefPath,
	type JsonNodeSchema,
	type JsonNodeSchemaBase,
	type JsonTreeSchema,
	type JsonFieldSchema,
	type JsonLeafSchemaType,
	type TreeSchemaEncodingOptions,
	getJsonSchema,
	getSimpleSchema,
	type VerboseTreeNode,
	type TreeEncodingOptions,
	type VerboseTree,
	extractPersistedSchema,
	comparePersistedSchema,
	type ConciseTree,
	comparePersistedSchemaInternal,
	ViewSchema,
	type Unenforced,
	type System_Unsafe,
	type ArrayNodeCustomizableSchemaUnsafe,
	type MapNodeCustomizableSchemaUnsafe,
	type TreeViewAlpha,
	type TreeBranch,
	type TreeBranchEvents,
	tryGetSchema,
	applySchemaToParserOptions,
	cursorFromVerbose,
	verboseFromCursor,
	conciseFromCursor,
	createFromCursor,
	asTreeViewAlpha,
	customFromCursorStored,
	type CustomTreeNode,
	type CustomTreeValue,
	tryStoredSchemaAsArray,
	type SchemaStatics,
	type ITreeAlpha,
	type TransactionConstraint,
	type NodeInDocumentConstraint,
	type RunTransactionParams,
	type VoidTransactionCallbackStatus,
	type TransactionCallbackStatus,
	type TransactionResult,
	type TransactionResultExt,
	type TransactionResultSuccess,
	type TransactionResultFailed,
	rollback,
	generateSchemaFromSimpleSchema,
	replaceConciseTreeHandles,
	replaceHandles,
	replaceVerboseTreeHandles,
	type HandleConverter,
	allowUnused,
	type FieldSchemaAlphaUnsafe,
	type TreeSchema,
} from "./api/index.js";
export type {
	SimpleTreeSchema,
	SimpleNodeSchema,
	SimpleFieldSchema,
	SimpleLeafNodeSchema,
	SimpleMapNodeSchema,
	SimpleArrayNodeSchema,
	SimpleObjectNodeSchema,
	SimpleNodeSchemaBase,
	SimpleObjectFieldSchema,
} from "./simpleSchema.js";
export {
	type NodeFromSchema,
	isTreeNodeSchemaClass,
	type ImplicitFieldSchema,
	type TreeFieldFromImplicitField,
	type ImplicitAllowedTypes,
	type TreeNodeFromImplicitAllowedTypes,
	type InsertableTreeNodeFromImplicitAllowedTypes,
	type TreeLeafValue,
	type AllowedTypes,
	FieldKind,
	FieldSchema,
	type FieldSchemaAlpha,
	type InsertableTreeFieldFromImplicitField,
	type InsertableTypedNode,
	type NodeBuilderData,
	type DefaultProvider,
	type FieldProps,
	normalizeFieldSchema,
	areFieldSchemaEqual,
	areImplicitFieldSchemaEqual,
	type ApplyKind,
	type FieldSchemaMetadata,
	type InsertableField,
	type Insertable,
	type UnsafeUnknownSchema,
	normalizeAllowedTypes,
	type ApplyKindInput,
	type InsertableTreeNodeFromAllowedTypes,
	type Input,
	type ReadableField,
	type ReadSchema,
	type NodeSchemaOptions,
	type NodeSchemaMetadata,
	evaluateLazySchema,
} from "./schemaTypes.js";
export {
	getTreeNodeForField,
	prepareContentForHydration,
} from "./proxies.js";
export {
	TreeArrayNode,
	IterableTreeArrayContent,
	type ReadonlyArrayNode,
} from "./arrayNode.js";
export type {
	ArrayNodeCustomizableSchema,
	ArrayNodePojoEmulationSchema,
} from "./arrayNodeTypes.js";
export { ArrayNodeSchema, isArrayNodeSchema } from "./arrayNodeTypes.js";
export type {
	MapNodeCustomizableSchema,
	MapNodePojoEmulationSchema,
} from "./mapNodeTypes.js";
export { MapNodeSchema, isMapNodeSchema } from "./mapNodeTypes.js";
export {
	type FieldHasDefault,
	type InsertableObjectFromSchemaRecord,
	type ObjectFromSchemaRecord,
	type TreeObjectNode,
	setField,
	createUnknownOptionalFieldPolicy,
} from "./objectNode.js";
export { ObjectNodeSchema } from "./objectNodeTypes.js";
export type { TreeMapNode, MapNodeInsertableData } from "./mapNode.js";
export {
	mapTreeFromNodeData,
	type InsertableContent,
	type FactoryContent,
	type FactoryContentObject,
} from "./toMapTree.js";
export { toStoredSchema, getStoredSchema } from "./toStoredSchema.js";
export {
	numberSchema,
	stringSchema,
	booleanSchema,
	handleSchema,
	nullSchema,
} from "./leafNodeSchema.js";
export type { LeafSchema } from "./leafNodeSchema.js";
export type { LazyItem, FlexList, FlexListToUnion, ExtractItemType } from "./flexList.js";
